@@ -176,6 +176,14 @@ class OntoEditor:
             self.logger.error("ontology file did not exist")
             sys.exit(1)
 
+    def _transform_to_dp_type(self, data_type: str, val):
+        if data_type != "boolean":
+            return self._dp_range_types[data_type](val)
+        elif str(val).lower() == "false":
+            return False
+        elif str(val).lower() == "true":
+            return True
+
     def add_import(self, other_path: str) -> None:
         """ load an additional onto
 
@@ -401,7 +409,7 @@ class OntoEditor:
             if resinfo[2] in ["some", "only"]:
                 obj = self._dp_constraint(dpinfo)
             elif resinfo[2] in ["value"] and dpinfo[3]:
-                obj = self._dp_range_types[dpinfo[0]](dpinfo[3])
+                obj = self._transform_to_dp_type(dpinfo[0], dpinfo[3])
             if obj is None:
                 self.logger.warning(f"invalid dp constraint: {axiom}")
                 return None
@@ -473,8 +481,7 @@ class OntoEditor:
             self.logger.warning(f"unexpected dp range restriction: {dpres}")
         return dp_range
 
-    @staticmethod
-    def _check_available_vals(values: list, expected_values: list) -> bool:
+    def _check_available_vals(self, values: list, expected_values: list) -> bool:
         """
         :param values: list with values
         :param expected_values: list with indices of expected values
@@ -482,10 +489,14 @@ class OntoEditor:
         """
         indices = [x for x, _ in enumerate(values)]
         assert all(x in indices for x in expected_values), "invalid expected_values"
-        test = all(values[i] for i in expected_values) and\
-               not any(values[i] for i in [e for e in indices if e not in expected_values])
+        test = all(self._check_value_validity(values[i]) for i in expected_values) and\
+               not any(self._check_value_validity(values[i]) for i in [e for e in indices if e not in expected_values])
         return test
 
+    @staticmethod
+    def _check_value_validity(value) -> bool:
+        return value is not None and value != ""
+
     def add_gcas(self, gcas: list) -> None:
         """ workaround for representing General Class Axioms
         adds two helper classes, each defined via an axiom, that are defined to be equivalent
@@ -555,7 +566,7 @@ class OntoEditor:
                         my_dp.domain.append(self.onto[dp[3]])
                     except Exception:
                         self.logger.warning(f"unexpected dp domain: {dp}")
-                if any(dp[4:]):
+                if any(self._check_value_validity(d) for d in dp[4:]):
                     dprange = self._dp_constraint(dp[4:])
                     if dprange:
                         my_dp.range = dprange
@@ -578,13 +589,13 @@ class OntoEditor:
                     self.logger.warning(f"unexpected instance info: {inst}")
                 if not any(inst[2:]):
                     continue
-                if inst[2] and inst[3]:
+                if inst[2] and self._check_value_validity(inst[3]):
                     pred = self.onto[inst[2]]
                     if DataProperty in pred.is_a:
                         if inst[4] and not inst[4] in self._dp_range_types:
                             self.logger.warning(f"unexpected DP range: {inst}")
                         elif inst[4]:
-                            val = self._dp_range_types[inst[4]](inst[3])
+                            val = self._transform_to_dp_type(inst[4], inst[3])
                         else:
                             self.logger.warning(f"DP range undefined - defaulting to string: {inst}")
                             val = inst[3]
